@@ -2,19 +2,15 @@ package CORBA::MICO;
 
 use strict;
 no strict qw(refs);
+require Carp;
 use vars qw($VERSION @ISA);
 
 require DynaLoader;
 require Error;
 
-require CORBA::MICO::Fixed;
-require CORBA::MICO::LongLong;
-require CORBA::MICO::ULongLong;
-require CORBA::MICO::LongDouble;
-
 @ISA = qw(DynaLoader);
 
-$VERSION = '0.6.7';
+$VERSION = '0.1';
 
 bootstrap CORBA::MICO $VERSION;
 
@@ -29,28 +25,16 @@ sub import {
 	my @ids = @{$keys{ids}};
 	while (@ids) {
 	    my ($id, $idlfile) = splice(@ids,0,2);
-
-	    eval { $orb->preload($id); };
-	    if( $@ ) {
-		require Carp;
-		Carp::carp("Could not preload '$id'");
-	    } 
+	    $orb->preload($id) || Carp::carp("Could not preload '$_'");
 	}
     }
-
-    if (exists $keys{'wait'}) {
-	CORBA::MICO::debug_wait();
-    }
-
 }
 
 package CORBA::Object;
 
-use Carp;
-
 use vars qw($AUTOLOAD);
 sub AUTOLOAD {
-    my ($self, @rest) = @_;
+    my $self = $_[0];
 
     my ($method) = $AUTOLOAD =~ /.*::([^:]+)/;
 
@@ -61,39 +45,25 @@ sub AUTOLOAD {
     }
 
     my $id = $self->_repoid;
-
-    my $newclass = CORBA::MICO::find_interface ($id);
-
-    if (!defined $newclass) {
+    
+    if (exists $CORBA::MICO::_interfaces{$id}) {
+	print STDERR "Already loaded $id\n";
+	die "No such method\n";
+    } else {
+#	print STDERR "Loading $id\n";
 	my $iface = $self->_get_interface;
 	defined $iface or print "Can't get interface\n";
-	$newclass = CORBA::MICO::load_interface ($iface);
-    }
-
-    defined $newclass or die "Can't get interface interformation";
-
-    my ($oldclass) = "$self" =~ /:*([^=]*)/;
-    $oldclass ne $newclass or 
-	croak qq(Can\'t locate object method "$method" via package "$oldclass");
-    
-    bless $self, $newclass;
+	my $newclass = CORBA::MICO::load_interface ($iface);
 
+	bless $self, $newclass;
+	
 #       The following goto doesn't work for some reason - 
 #       the mark stack isn't set correctly.
 #	goto &{"$ {newclass}::$ {method}"};
-
-# This is decent, but gets the call stack wrong
-    $self->$method(@rest);
+	&{"$ {newclass}::$ {method}"}(@_);
+    }
 }
 
-@POA_PortableServer::ServantActivator::ISA = qw(PortableServer::ServantBase);
-@POA_PortableServer::ServantLocator::ISA = qw(PortableServer::ServantBase);
-@POA_PortableServer::AdapterActivator::ISA = qw(PortableServer::ServantBase);
-
-package CORBA::MICO::GtkDispatcher;
-
-@CORBA::MICO::GtkDispatcher::ISA = qw(CORBA::Dispatcher);
-
 package CORBA::Exception;
 
 @CORBA::Exception::ISA = qw(Error);
@@ -133,27 +103,6 @@ sub new {
     }
 }
 
-package DynamicAny;
-
-package DynamicAny::DynAny;
-
-package DynamicAny::DynFixed;
-@DynamicAny::DynFixed::ISA    = qw(DynamicAny::DynAny);
-package DynamicAny::DynEnum;
-@DynamicAny::DynEnum::ISA     = qw(DynamicAny::DynAny);
-package DynamicAny::DynStruct;
-@DynamicAny::DynStruct::ISA   = qw(DynamicAny::DynAny);
-package DynamicAny::DynUnion;
-@DynamicAny::DynUnion::ISA    = qw(DynamicAny::DynAny);
-package DynamicAny::DynSequence;
-@DynamicAny::DynSequence::ISA = qw(DynamicAny::DynAny);
-package DynamicAny::DynArray;
-@DynamicAny::DynArray::ISA    = qw(DynamicAny::DynAny);
-package DynamicAny::DynValue;
-@DynamicAny::DynArray::ISA    = qw(DynamicAny::DynAny);
-
-package DynamicAny::DynAnyFactory;
-
 # Preloaded methods go here.
 
 # Autoload methods go after =cut, and are processed by the autosplit program.
@@ -230,35 +179,7 @@ Returns the value of the any.
 
 =over 4
 
-=item impl_is_ready ( IMPLEMENTATION_DEF )
-
-=item deactivate_impl ( IMPLEMENTATION_DEF )
-
-=item obj_is_ready ( OBJ, IMPLEMENTATION_DEF )
-
-=item deactivate_obj ( OBJ )
-
-=item dispose ( OBJ )
-
-=back
-
-=head1 Methods of CORBA::BOAObjectRestorer
-
-=over 4
-
-=item new
-
-=item add_binders ( [ REPOID => CALLBACK ] ... )
-
-=item add_restorers ( [ REPOID => CALLBACK ] ... )
-
-=back
-
-=head1 Methods of CORBA::MICO::GtkDispatcher
-
-=over 4
-
-=item new
+=item impl_is_ready ( [ IMPLEMENTATION_DEF ] )
 
 =back
 
@@ -266,58 +187,33 @@ Returns the value of the any.
 
 =over 4
 
-=item _boa
-
-=item _ident
-
 =item _get_interface
 
 =item _get_implementation
 
-=item _self
-
-=item _restore
-
-=item _repoid
-
 =item _set_repoid (  REPOID  )
 
 Specify the repository ID of the interface that this
 object implements.
 
+=item _repoid
+
 =back
 
 =head1 Methods of CORBA::ORB
 
 =over 4
 
-=item bind ( REPOID, [ OBJECT_TAG [, ADDR ]] )
-
 =item BOA_init ( ID )
 
-=item dispatcher ( DISPATCHER )
-
 =item object_to_string ( OBJ )
 
 =item resolve_initial_references ( ID )
 
 =item string_to_object ( STRING )
 
-=item run 
-
-=item shutdown ( WAIT_FOR_COMPLETION )
-
-=item perform_work
-
-=item work_pending
-
 =item preload ( REPOID )
 
-Force the interface specified by REPOID to be loaded from the
-Interface Repository. Returns a true value if REPOID represents
-interface (dk_Interface), false otherwise. In case of fail method
-calls Carp::croak().
-
 =back
 
 =head1 Methods of CORBA::TypeCode
@@ -338,11 +234,17 @@ the typecode constant.
 In the future, this scheme will probably be revised, or
 replaced.
 
+=item preload ( REPOID )
+
+Force the interface specified by REPOID to be loaded from the
+Interface Repository. Returns a true value if the operation
+succeeds.
+
 =back
 
 =head1 AUTHOR
 
-Owen Taylor <otaylor@gtk.org>
+Owen Taylor <owt1@cornell.edu>
 
 =head1 SEE ALSO
 
